html,
body {
    min-height: 100%;
    padding: 0;
    margin: 0;
}

#wrapper {
    padding: 0 0;
    position: absolute;
    top: 50px;
    bottom: 0;
    left: 0;
    right: 0;
}

#content {
    min-height: 100%;
}

.navbar {
    margin-top: -50px;
    height: 50px;
}

p {
    margin: 0;
    padding: 0 0 1em 0;
}
