.app .data .map {
    position: relative;
}

#cesiumContainer {
    width: 100%;
    height: 100%;
    margin: 0;
    padding: 0;
    position: absolute;
    z-index: 10;
}

.slidecontainer {
    background-color: #DCDCDC;
    padding: 2px;
    border: 1px solid #000;
    text-align: left;
    border-radius: 10px;
    position: absolute;
    opacity: 0.75;
    z-index: 100;
    top: 5px;
    left: 5px;
}
